#!/bin/sh

# Build script for ZynAddSubFX
# Author: Ejis <ejis@mailoo.org>

# Homepage: http://zynaddsubfx.sourceforge.net/


set -e


SOFTNAME=zynaddsubfx
VERSION=2.4.1
ZENVER=66
BUILD=1

CATEGORY=extra/xap

MARCH=i686
FLAGS="-O2 -march=$MARCH -mtune=i686"

DOTNEW=1

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/ZynAddSubFX-$VERSION
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep

SRCFILES=(
	ZynAddSubFX-$VERSION.tar.bz2
	$SOFTNAME-binary.patch
	$SOFTNAME-dssi.patch
)

HOSTURL=http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME/$ZENVER
SRCURLS=(
	http://downloads.sourceforge.net/project/zynaddsubfx/zynaddsubfx/$VERSION
	$HOSTURL
)

SRCLINKS=(
	${SRCURLS[0]}/${SRCFILES[0]}
	${SRCURLS[1]}/${SRCFILES[1]}
	${SRCURLS[1]}/${SRCFILES[2]}
)

DOC=(
	$SOFTDIR/AUTHORS.txt
	$SOFTDIR/ChangeLog
	$SOFTDIR/COPYING
	$SOFTDIR/FAQ.txt
	$SOFTDIR/HISTORY.txt
	$SOFTDIR/README.txt
)

EXTRADEPS=(
)

LESSDEPS=(
)


# Check for source files and download them if necessary

if [ ! -f ${SRCFILES[0]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]}
fi

if [ ! -f ${SRCFILES[1]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[1]}
fi

if [ ! -f ${SRCFILES[2]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[2]}
fi


# Erase the previous build files

rm -rf $PKGFILE $SOFTDIR $PKGDIR $MD5 $SRC $DEP
mkdir -p $PKG


# Build

echo ""
echo "-----Building-----"
echo ""

tar -xvf $CWD/${SRCFILES[0]}

cd $SOFTDIR/src

export CFLAGS=$FLAGS
export CXXFLAGS=$FLAGS


mkdir -pv $PKGDIR/usr/bin
mkdir -pv $PKGDIR/usr/lib/dssi
mkdir -pv $PKGDIR/usr/share/$SOFTNAME
mkdir -v $PKGDIR/usr/share/$SOFTNAME/banks
mkdir -v $PKGDIR/usr/share/$SOFTNAME/examples
mkdir -pv $PKGDIR/usr/share/applications
mkdir -pv $PKGDIR/usr/share/icons/hicolor/48x48/apps


patch -p2 < $CWD/${SRCFILES[1]}

make

cp -v $SOFTDIR/src/zynaddsubfx $PKGDIR/usr/bin/zynaddsubfx


patch -p2 < $CWD/${SRCFILES[2]}

make clean
make

cp -v $SOFTDIR/src/zynaddsubfx.so $PKGDIR/usr/lib/dssi/


cp -v $SOFTDIR/zynaddsubfx_icon.ico \
	$PKGDIR/usr/share/$SOFTNAME/zynaddsubfx_icon.ico
cp -rvf $SOFTDIR/banks/* $PKGDIR/usr/share/$SOFTNAME/banks
cp -rvf $SOFTDIR/examples/* $PKGDIR/usr/share/$SOFTNAME/examples
convert $SOFTDIR/zynaddsubfx_icon.ico \
	$PKGDIR/usr/share/icons/hicolor/48x48/apps/$SOFTNAME.png

cat << EOF > $PKGDIR/usr/share/applications/zynaddsubfx.desktop
[Desktop Entry]
Encoding=UTF-8
Name=ZynAddSubFX
Comment=Virtual synthesizer
Exec=zynaddsubfx
Icon=zynaddsubfx
Terminal=false
Type=Application
X-MultipleArgs=false
Categories=GTK;Audio;AudioVideo;AudioVideoEditing;Multimedia
EOF


# Packaging

echo ""
echo "-----Packaging-----"
echo ""

cd $PKGDIR

mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


	       #|-----handy-ruler------------------------------------------------------|
cat << EOF > $PKGDIR/install/slack-desc
$SOFTNAME: $SOFTNAME
$SOFTNAME:
$SOFTNAME: ZynAddSubFX is a opensource software synthesizer capable of
$SOFTNAME: making a countless number of instruments, from some common heared
$SOFTNAME: from expensive hardware to interesting sounds that you'll boost to
$SOFTNAME: an amazing universe of sounds.
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
EOF


# Redundent

if [ -d $PKGDIR/usr/share/doc ]; then
	mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
	rm -rvf $PKGDIR/usr/share/doc
fi

if [ -d $PKGDIR/etc ]; then
	if [ $DOTNEW == 1 ]; then
		dotnewfiles=$(find $PKGDIR/etc -type f -print -exec \
			mv {} {}.new \;)
		cat << EOF > $PKGDIR/install/doinst.sh
dotnewfiles=(${dotnewfiles[@]})

for file in \${dotnewfiles[@]}; do
	if [ ! -f \$file ]; then
		mv \$file.new \$file
	fi
done
EOF
		sed -i "s:$PKGDIR/::g" $PKGDIR/install/doinst.sh
	fi
fi

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true

if [ -d $PKGDIR/usr/man ]; then
	
	( cd $PKGDIR/usr/man
		find . -type f -exec gzip -9 {} \;
		for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
	)
	
fi

if [ -d $PKGDIR/usr/info ]; then
	
	rm -f $PKGDIR/usr/info/dir
	gzip -9 $PKGDIR/usr/info/*.info*
	
fi

find . -name perllocal.pod \
	-o -name ".packlist" \
	-o -name "*.bs" \
	| xargs rm -f


cp -v $CWD/build-$SOFTNAME.sh \
	$CWD/${SRCFILES[1]} \
	$CWD/${SRCFILES[2]} \
	$PKGDIR/usr/src/$SOFTNAME-$VERSION/

cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


# fix permissions
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;


fakeroot /sbin/makepkg -l y -c n $PKGFILE


cd $CWD

echo 'Creating .md5 file'
md5sum $PKG.txz > $MD5

echo 'Creating .src file'
echo "$HOSTURL/build-$SOFTNAME.sh" > $SRC
for link in ${SRCLINKS[@]}; do
	echo $link >> $SRC
done

echo 'Checking for dependencies'
deps=$(depfinder $PKGFILE)

for dep in ${EXTRADEPS[@]}; do
	deps="$deps,$dep"
done

for dep in ${LESSDEPS[@]}; do
	deps=${deps/$dep/}
done

order=$(echo ${deps//,/ } | sort -d)
echo ${order// /,} > $DEP

echo "Removing build directories"
rm -rf $SOFTDIR $PKGDIR
